Documentation
¶
Index ¶
Constants ¶
const OpenApplication = "open_application"
OpenApplication is the custom ID used for the "open application" button
Variables ¶
var Log = zap.S()
Log is the global logger.
var Version = ""
Version is the git commit hash.
Functions ¶
func ExecTemplate ¶
ExecTemplate executes a template string into a string.
func IsOodlesError ¶
IsOodlesError returns true if the given error is an OodlesError (user error)
Types ¶
type BotConfig ¶
type BotConfig struct {
Token string `toml:"token"`
Database string `toml:"database"`
// Immutable owners, have access to all commands regardless of overrides (except disabled commands)
Owners []discord.UserID `toml:"owners"`
GuildID discord.GuildID `toml:"guild_id"`
// Where errors and DMs are sent
LogChannel discord.ChannelID `toml:"log_channel"`
Help struct {
Title string `toml:"title"`
Description string `toml:"description"`
Fields []EmbedField `toml:"fields"`
} `toml:"help"`
}
BotConfig is the bot's configuration file. This contains authentication as well as data that is too complicated to store in a key-value format.
type EmbedField ¶
EmbedField ...
type OodlesError ¶
type OodlesError string
OodlesError is an error that should be shown to the user directly
func (OodlesError) Error ¶
func (e OodlesError) Error() string
Directories
¶
| Path | Synopsis |
|---|---|
|
Package parameters provides an argument parser for dealing with a mix of quoted and unquoted arguments.
|
Package parameters provides an argument parser for dealing with a mix of quoted and unquoted arguments. |
Click to show internal directories.
Click to hide internal directories.